@@ -50,7 +50,7 @@ async fn main() -> Result<(), Box<dyn Error>> {
                         NetXClient::new(ServerOption::new(format!("{}:6666",ipaddress),
                                                           "".into(),
                                                           "123123".into(),
-                                                          60000),
+                                                          6000),
                                                         DefaultSessionStore::default(),"localhost".to_string(),ssl_connector)
 
                 }else if #[cfg(feature = "tcp")]{
@@ -59,7 +59,7 @@ async fn main() -> Result<(), Box<dyn Error>> {
                         NetXClient::new(ServerOption::new(format!("{}:6666",ipaddress),
                                                           "".into(),
                                                           "123123".into(),
-                                                          60000),
+                                                          6000),
                                                         DefaultSessionStore::default())
                 }}
             };
@@ -73,7 +73,7 @@ async fn main() -> Result<(), Box<dyn Error>> {
             let start = Instant::now();
             for i in 0..count {
                 if let Err(er) = server.add(1, i as i32).await {
-                    error!("{}", er);
+                    error!("send error:{}", er);
                 }
             }
             info!("task:{} use {} ms", id, start.elapsed().as_millis());
